proxy — Health Dashboard

# proxy — Good

Analyzed 2026-03-24 by code2llm · Primary language: python · Python: 170, JavaScript: 72, Shell: 8

2,138
Functions
208
Classes
217
Files
58,422
Lines
3
Languages
4.6
Avg CC
208
Critical (CC≥10)
1
Duplicates
0
Cycles

## Language Distribution

## Largest Modules (lines)

## Most Complex Modules (functions)

## Evolution

## Top Modules (250)

Module | Path | Lines | Funcs | Classes | CC max
--- | --- | --- | --- | --- | ---
tasks.jsx | src/proxym/dashboard/components | 1,697 | 110 | 0 | 129
tools.jsx | src/proxym/dashboard/components | 1,586 | 112 | 0 | 87
tickets.jsx | src/proxym/dashboard/components | 1,473 | 89 | 0 | 94
projects.jsx | src/proxym/dashboard/components | 1,070 | 72 | 0 | 129
users.py | src/proxym/dashboard | 928 | 58 | 3 | 13
coverage_html_cb_dd2e7eb5.js | htmlcov | 735 | 65 | 0 | 21
_tickets_api.py | src/proxym/dashboard | 676 | 25 | 8 | 18
setup.jsx | src/proxym/dashboard/components | 649 | 33 | 0 | 36
environments.jsx | src/proxym/dashboard/components | 611 | 30 | 0 | 59
__init__.py | src/proxym/tools | 572 | 19 | 5 | 10
validate_system.sh | scripts | 531 | 11 | 0 | 0
_manager.py | src/proxym/dashboard/tickets | 464 | 34 | 1 | 22
_environments_api.py | src/proxym/dashboard | 460 | 33 | 6 | 13
users.jsx | src/proxym/dashboard/components | 457 | 21 | 0 | 24
executor.py | src/proxym/tools | 426 | 18 | 3 | 25
useDashboardData.js | src/proxym/dashboard/hooks | 399 | 67 | 0 | 24
__init__.py | src/proxym/accounts | 398 | 20 | 8 | 15
entrypoint.sh | services/vscode | 369 | 1 | 0 | 0
human.jsx | src/proxym/dashboard/components | 366 | 18 | 0 | 65
project_handler.py | src/proxym/domain/handlers | 362 | 12 | 2 | 28

## Alerts (20)

Severity | Target | Type | Value | Limit
--- | --- | --- | --- | ---
critical | TasksPanel | cc_exceeded | 129 | 15
critical | ProjectFormUnified | cc_exceeded | 129 | 15
critical | TicketDetailPanel | cc_exceeded | 94 | 15
critical | TicketDispatchTable | cc_exceeded | 87 | 15
critical | TicketsPanel | cc_exceeded | 87 | 15
critical | JobDetailsPanel | cc_exceeded | 77 | 15
critical | ToolHealthPanel | cc_exceeded | 76 | 15
critical | HumanTaskPanel | cc_exceeded | 65 | 15
critical | EnvironmentsPanel | cc_exceeded | 59 | 15
critical | ToolsPanel | cc_exceeded | 57 | 15
critical | TicketsPanel | high_fan_out | 56 | 10
critical | ToolsJobQueue | cc_exceeded | 48 | 15
critical | TasksPanel | high_fan_out | 46 | 10
critical | useDashboardData | high_fan_out | 44 | 10
critical | TicketCard | cc_exceeded | 42 | 15

## Hotspots (10)

Function | Fan-out | Note
--- | --- | ---
TicketsPanel | 56 | Orchestrates 56 calls
TasksPanel | 46 | Orchestrates 46 calls
useDashboardData | 44 | Orchestrates 44 calls
EnvironmentsPanel | 42 | Orchestrates 42 calls
SetupPanel | 36 | Orchestrates 36 calls
create_ticket | 31 | Create a new ticket. Accepts 'task' (new) or 'title' (legacy).
VoiceChat | 31 | Orchestrates 31 calls
ProjectFormUnified | 31 | Orchestrates 31 calls
DiagnosticsPanel | 30 | Orchestrates 30 calls
run_all_tests | 28 | Run all diagnostic tests and return comprehensive status.

## Refactoring Priorities (15)

# | Action | Impact | Effort
--- | --- | --- | ---
1 | Split ToolExecutor._sync_ticket_execution (CC=25 → target CC<10) | high | low
2 | Split enrich_project (CC=28 → target CC<10) | high | low
3 | Split DiagnosticsPanel (CC=40 → target CC<10) | high | low
4 | Split LogPanel (CC=34 → target CC<10) | high | low
5 | Split HumanTaskPanel (CC=65 → target CC<10) | high | low
6 | Split VMsPanel (CC=36 → target CC<10) | high | low
7 | Split _resolveJobEnvironment (CC=25 → target CC<10) | high | low
8 | Split TaskCardMeta (CC=37 → target CC<10) | high | low
9 | Split TaskJobBadge (CC=25 → target CC<10) | high | low
10 | Split TaskBulkEditBar (CC=30 → target CC<10) | high | low
11 | Split QuickTaskCreator (CC=31 → target CC<10) | high | low
12 | Split TasksPanel (CC=129 → target CC<10) | high | low
13 | Split ToolCard (CC=26 → target CC<10) | high | low
14 | Split JobRow (CC=35 → target CC<10) | high | low
15 | Split JobDetailsPanel (CC=77 → target CC<10) | high | low